##############################################################################
## Runs the MCMC sampler with the democratization/industrialization example from
##
## Bollen, K. (1989). ``Structural Equations with Latent Variables'',
##                     John Wiley & Sons.
##
## This data is also explained in:
##
## Silva, R. and Ghahramani, Z. (2008) ``The hidden life of latent variables:
## Bayesian learning with mixed graph models'' (google for it)
##
## NOTE: the actual datafile used in this example (bollen.synth.dat) is NOT the data
## from the original study. Instead it is synthetic data sampled from a model
## fitted to the original data. To have access to the original data, please
## contact Prof. Bollen directly.
## 
## For further explanation of this example, see also the document
## 
## Silva, R. (2008) ``A Tutorial on dmgBayes: Bayesian Analysis for 
##                    Directed Mixed Graph Models''


bollen.directed <- matrix(c(1,  12,
                            2,  12,
                            3,  12,
                            4,  13,
                            5,  13,
                            6,  13,
                            7,  13,
                            8,  14,
                            9,  14,
                            10, 14,
                            11, 14,
                            13, 12,
                            14, 12,
                            14, 13), nrow = 14, ncol = 2, byrow = TRUE)

bollen.bidirected <- matrix(c(4,  8,
                              5,  9,
                              6, 10,
                              7, 11,
                              5, 7,
                              9, 11), nrow = 6, ncol = 2, byrow = TRUE)

bollen.df = 10;

bollen.vprior <- matrix(c(1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                          0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                          0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                          0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                          0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                          0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0,
                          0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0,
                          0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0,
                          0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
                          0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0,
                          0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0,
                          0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0,
                          0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0,
                          0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1),
                          nrow = 14, ncol = 14)

bollen.bprior.mean <- c(0, 0, #X1 (edge from L1, then intercept)
                        0, 0, #X2 (etc.)
                        0, 0, #X3
                        0, 0, #X4
                        0, 0, #X5
                        0, 0, #X6
                        0, 0, #X7
                        0, 0, #X8
                        0, 0, #X9
                        0, 0, #X10
                        0, 0, #X11
                        0,    #L1 (no edges into L1, just intercept)
                        0, 0, #L2
                        0, 0, 0); #L3 (edge from L1, edge from L2, intercept)

bollen.bprior.var <- c(1, 1, #X1
                       1, 1, #X2
                       1, 1, #X3
                       1, 1, #X4
                       1, 1, #X5
                       1, 1, #X6
                       1, 1, #X7
                       1, 1, #X8
                       1, 1, #X9
                       1, 1, #X10
                       1, 1, #X11
                       1,    #L1
                       1, 1, #L2
                       1, 1, 1); #L3

bollen.b.fixed <- rep(FALSE, length(bollen.bprior.mean))
bollen.islatent <- c(rep(FALSE, 11), TRUE, TRUE, TRUE)

mcmc.sample.size <- 5000
mcmc.burn.in <- 100
mcmc.step <- 1
mcmc.output.filename <- "bollen"
mcmc.options <- c(4, 0)

bollen.train <- read.table("bollen.synth.dat", header = T)

bollen.var.names <- c(names(bollen.train), "L1", "L2", "L3")

dmgbayes.gaussiansample(bollen.var.names, bollen.directed, bollen.bidirected, bollen.train, bollen.islatent,
                bollen.vprior, bollen.df, bollen.bprior.mean, bollen.bprior.var, bollen.b.fixed,
                mcmc.sample.size, mcmc.burn.in, mcmc.step, mcmc.output.filename, mcmc.options)

cat("File \"", mcmc.output.filename, ".mcmc\" created. Read it with 'posterior.samples <- read.table(\"", mcmc.output.filename, ".mcmc\", header = T)'\n", sep="")
                