
\name{dmgbayes.gaussiansample}

\alias{dmgbayes.gaussiansample}

\title{MCMC sampler for the parameters of a Gaussian directed mixed graph models}

\description{
   A Gibbs sampling procedure to sample parameters from the posterior distribution
   of a Gaussian model that is parameterized by a Gaussian directed mixed graph
   model. The output is stored in a data file.
}

\usage{
   dmgbayes.gaussiansample(var.names, directed, bidirected, train, islatent,
                           prior.V, dmg.df, b.priormean, b.priorvar, b.fixed,
                           mcmc.num.samples, mcmc.burn.in, mcmc.step,
                           output.filename, mcmc.options, test = NULL)
}

\arguments{
\item{var.names}{Array of string naming all variables (observed and latents)}
\item{directed}{A m x 2 array, where each row (i, j) encodes a directed edge from
             the jth variable into the ith variable. All variables should be
             encoded as integers (1, 2, 3, ...), and their number should match
             the corresponding entry in var.names}
\item{bidirected}{A m' x 2 array, m' being the total number of bi-directed edges.
               As above, each two-dimensional row (i, j) encodes a bi-directed
               edge connecting the ith and jth variables}
\item{train}{Data which we condition on when computing the posterior}
\item{islatent}{Binary array, indicating with '1' which variables in var.names are
                unobserved variables}
\item{prior.V}{A p x p matrix with the matrix parameter of the G-Inverse Wishart
            prior for the covariance matrix of the error terms}
\item{dmg.df}{Degrees of freedom of the same prior}
\item{b.priormean}{A (m + p) dimensional array contaning the mean parameter of the
                Gaussian prior for each coefficient associated with the
                respective directed edge. *IMPORTANT*: remember that we have
                to consider the intercept terms too. The intercept term
                for each variable $Y_i$ should be located just after the other
                coefficients for $Y_i$. This explains why this afrray has
                m + p dimensions}
\item{b.priorvar}{The respective variances}
\item{b.fixed}{A (m + p) dimensional binary array indicating with '1' those coefficients
            that are to be fixed to a constant value. The constant to be used
            is the respective entry in b.priormean. *REMEMBER*: intercepts
            should be considered}
\item{mcmc.num.samples}{Total number of samples to be generated in the Markov chain}
\item{mcmc.burn.in}{Total number of initial samples to be skipped when storing the
                    results of the chain (minimum value: 0)}
\item{mcmc.step}{Interval between points that will be stored in the output file}
\item{output.filename}{Name of the file to which samples points will be stored}
\item{mcmc.options}{A numeric array contain miscellaneous options:
      mcmc.options[1] is a number between 1 and 4 indicating verbosity 
      level of output messages returned to the R console;
      mcmc.options[2] should be set to '1' if you want to generate a file
      with sampled latents. This file will be called 'output.filename'.latents}
\item{test}{Optional matrix with test data to be evaluated by predictive
           log-likelihood}
}

\references{Silva, R. (2008). "A Tutorial on dmgBayes: Bayesian Analysis for Directed Mixed Graph Models"}

\author{Ricardo Silva, Statistical Laboratory, University of Cambridge}

\keyword{ts}

\keyword{array}

\seealso{\code{\link{dmgbayes.gaussian.marginal.bidirected}}}
