package rbas.dmg.app;

import edu.cmu.tetrad.data.RectangularDataSet;
import edu.cmu.tetrad.graph.Graph;
import rbas.dmg.sem.McmcGaussianMixedGraph;

/**
 * RunGaussianBidirectedScoring
 *
 * Application for calculating marginal log-likelihoods of Gaussian bi-directed models.
 *
 * @author Ricardo Silva
 * @version $Revision: 0.1 $ $Date: 2007/07/02$
 */


public class RunGaussianBidirectedScoring {

    public static void main(final String[] argv) {
        System.out.println();
        System.out.println("** DMG MODELING SOFTWARE: MARGINAL LIKELIHOOD FOR GAUSSIAN BIDIRECTED MODELS");
        System.out.println("Code: Ricardo Silva, Gatsby Computational Neuroscience Unit");
        System.out.println("Version: 0.2 - October 2007");

        if (argv.length != 2) {
            System.out.println("Usage: rbas.dmg.app.RunGaussianBidirectedScoring <domain_name> <#samples>");
            System.out.println("Requires: files domain_name.graph, domain_name.train, domain_name.priors");
        }

        try {
            System.out.println("Loading... " + argv[0] + ".train");
            RectangularDataSet data = Loader.loadDataSet(argv[0] + ".train");
            Graph graph = Loader.loadGraph(argv[0] + ".graph", data.getVariableNames());
            rbas.util.RbasGraphUtils.printEdges(graph);
            double vPrior[][] = new double[graph.getNodes().size()][graph.getNodes().size()];
            double df[] = new double[1];
            double bPrior[][][] = new double[graph.getNodes().size()][][];
            boolean fixedB[][] = new boolean[graph.getNodes().size()][];
            Loader.loadPriors(argv[0] + ".priors", vPrior, df, bPrior, fixedB, null, null, graph);
            McmcGaussianMixedGraph sampler = new McmcGaussianMixedGraph(graph, data, vPrior, df[0], bPrior, fixedB);
            scoreBidirected(sampler, Integer.parseInt(argv[1]));
        } catch (java.io.IOException e) {
            System.out.println("File not loaded!");
            System.exit(0);
        }
	}

    public static double scoreBidirected(McmcGaussianMixedGraph mcmc, int simulationSize) {
        java.util.Date date1 = new java.util.Date();
        McmcGaussianMixedGraph.logger.fine("Computing marginal loglikelihood... ");
        double ll = mcmc.bidirectedMarginalLoglikelihood(simulationSize);
        System.out.println(ll);
        java.util.Date date2 = new java.util.Date();
        McmcGaussianMixedGraph.logger.fine("Started at " + date1.toString() + ", finished at " + date2.toString());
        return ll;
    }

}
