package rbas.util;

/**
 * Complements MatrixUtils by wrapping a few more specialized matrix operations.
 *
 * @author Ricardo Silva
 * @version $Revision: 1.0 $ $Date: 2006/09/12$
 */


public class RbasMatrixUtils {

    public static double[][] invertDiagonalMatrix(double matrix[][]) {
        double output[][] = new double[matrix.length][matrix.length];
        for (int i = 0; i < matrix.length; i++)
            output[i][i] = 1. / matrix[i][i];
        return output;
    }

    public static double[][] invertLowerTriangular(double matrix[][]) {
        int n = matrix.length;
        double inverse[][] = new double[n][n];
        for (int i = 0; i < n; i++)
             System.arraycopy(matrix[i], 0, inverse[i], 0, n);

        invertLower(inverse, n);
        return inverse;
    }

    //Adapted from http://www1.fpl.fs.fed.us/Triangular.html

    /*
    Triangular.java copyright claim:

    Copyright (C) 1996 by Steve Verrill.

    This class is free software; you can redistribute it and/or
    modify it under the terms of version 2 of the GNU General
    Public License as published by the Free Software Foundation.

    This class are distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with these programs in the file COPYING; if not, write to
    the Free Software Foundation, Inc., 675 Mass Ave, Cambridge,
    MA 02139, USA.

    The author's mail address is:

    Steve Verrill
    USDA Forest Products Laboratory
    1 Gifford Pinchot Drive
    Madison, Wisconsin
    53705

    The author's e-mail address is:

    steve@swst.org


    ***********************************************************************

    DISCLAIMER OF WARRANTIES:

    THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND.
    THE AUTHOR DOES NOT WARRANT, GUARANTEE OR MAKE ANY REPRESENTATIONS
    REGARDING THE SOFTWARE OR DOCUMENTATION IN TERMS OF THEIR CORRECTNESS,
    RELIABILITY, CURRENTNESS, OR OTHERWISE. THE ENTIRE RISK AS TO
    THE RESULTS AND PERFORMANCE OF THE SOFTWARE IS ASSUMED BY YOU.
    IN NO CASE WILL ANY PARTY INVOLVED WITH THE CREATION OR DISTRIBUTION
    OF THE SOFTWARE BE LIABLE FOR ANY DAMAGE THAT MAY RESULT FROM THE USE
    OF THIS SOFTWARE.

    Sorry about that.

    ***********************************************************************

    History:

    Date        Author            Changes

    11/30/96    Steve Verrill     Created

    */

    /**
     * This method obtains the solution, x, of the equation Ux = y where U is a known full rank lower triangular
     * n by n matrix, and y is a known vector of length n.
     */

    public void solveLower (double l[][], double y[], double b[], int n) {
        double sum;
        int i,j;

        for (i = 0; i < n; i++) {
            sum = 0.0;
            for (j = 0; j < i; j++) {
                sum += l[i][j]*y[j];
            }
            y[i] = (b[i] - sum)/l[i][i];
        }
    }

    /**
     * This method obtains the solution, x, of the equation Ux = y where U is a known full rank upper triangular
     * n by n matrix, and y is a known vector of length n.
     */

    public void solveUpper (double u[][], double x[], double y[], int n) {
        double sum;
        int i,j;

        for (i = n - 1; i > -1; i--) {
            sum = 0.0;
            for (j = i + 1; j < n; j++) {
                sum += u[i][j]*x[j];
            }
            x[i] = (y[i] - sum)/u[i][i];
        }
    }

    /** This method obtains the inverse of a lower
     *  triangular n by n matrix L. L must have non-zero
     *  diagonal elements. On exit L is replaced by its inverse.
     */

    public static void invertLower (double l[][], int n) {
        double sum; int i,j,k;

        for (j = 0; j < n; j++) {
            l[j][j] = 1.0/l[j][j];
            for (i = j + 1; i < n; i++) {
                sum = 0.0;
                for (k = j; k < i; k++) {
                    sum -= l[i][k]*l[k][j];
                }
                l[i][j] = sum/l[i][i];
            }
        }
    }

    /** This method obtains the inverse of a lower
     *  triangular n by n matrix L. L must have non-zero
     *  diagonal elements. On exit L is replaced by its inverse.
     */

    public static void invertUpper (double u[][], int n) {
        double sum;
        int i,j,k;

        for (j = n - 1; j > -1; j--) {
            u[j][j] = 1.0/u[j][j];
            for (i = j - 1; i > -1; i--) {
                sum = 0.0;
                for (k = j; k > i; k--) {
                    sum -= u[i][k]*u[k][j];
                }
                u[i][j] = sum/u[i][i];
            }
        }
    }
}
